@@ -1,10 +1,9 @@
 package Wubot::Plugin::FileRegexp;
 use Moose;
 
-our $VERSION = '0.2_001'; # VERSION
-
-use Log::Log4perl;
+our $VERSION = '0.2_002'; # VERSION
 
+use Wubot::Logger;
 use Wubot::Tail;
 
 has 'path'      => ( is      => 'rw',
@@ -80,3 +79,17 @@ sub check {
 }
 
 1;
+
+__END__
+
+=head1 NAME
+
+Wubot::Plugin::FileRegexp - monitor number of lines matching regular expressions in a file
+
+=head1 VERSION
+
+version 0.2_002
+
+=head1 DESCRIPTION
+
+TODO: More to come...
