@@ -1,11 +1,12 @@
 package Wubot::Reactor::Dumper;
 use Moose;
 
-our $VERSION = '0.2_001'; # VERSION
+our $VERSION = '0.2_002'; # VERSION
 
-use Log::Log4perl;
 use YAML;
 
+use Wubot::Logger;
+
 has 'logger'  => ( is => 'ro',
                    isa => 'Log::Log4perl::Logger',
                    lazy => 1,
@@ -40,7 +41,7 @@ Wubot::Reactor::Dumper - display the contents of a field or an entire message
 
 =head1 VERSION
 
-version 0.2_001
+version 0.2_002
 
 =head1 SYNOPSIS
 
