@@ -1,16 +1,17 @@
 package Wubot::Reactor::RRD;
 use Moose;
 
-our $VERSION = '0.2_001'; # VERSION
+our $VERSION = '0.2_002'; # VERSION
 
 use Capture::Tiny;
 use File::Path;
-use Log::Log4perl;
 use POSIX qw(strftime);
 use RRD::Simple;
 use RRDs;
 use YAML;
 
+use Wubot::Logger;
+
 has 'logger'  => ( is => 'ro',
                    isa => 'Log::Log4perl::Logger',
                    lazy => 1,
