@@ -1,13 +1,13 @@
 package Wubot::Reactor::WebFetch;
 use Moose;
 
-our $VERSION = '0.2_001'; # VERSION
+our $VERSION = '0.2_002'; # VERSION
 
-use Wubot::Util::WebFetcher;
-
-use Log::Log4perl;
 use YAML;
 
+use Wubot::Logger;
+use Wubot::Util::WebFetcher;
+
 has 'fetcher' => ( is  => 'ro',
                    isa => 'Wubot::Util::WebFetcher',
                    lazy => 1,
@@ -83,7 +83,7 @@ Wubot::Reactor::WebFetch - fetch data from a URL
 
 =head1 VERSION
 
-version 0.2_001
+version 0.2_002
 
 =head1 SYNOPSIS
 
